@@ -1,7 +1,9 @@
 import os
+import tempfile
 from io import BytesIO
 
 from botocore.exceptions import ClientError
+import aiofiles
 import pytest
 
 
@@ -82,6 +84,24 @@ async def test_s3_upload_fileobj(event_loop, s3_client, bucket_name):
     assert (await resp['Body'].read()) == data
 
 
+@pytest.mark.asyncio
+async def test_s3_upload_fileobj_async(event_loop, s3_client, bucket_name):
+    await s3_client.create_bucket(Bucket=bucket_name)
+
+    data = b'Hello World\n'
+
+    tmpfile = tempfile.NamedTemporaryFile(delete=False)
+    tmpfile.close()
+    async with aiofiles.open(tmpfile.name, mode='wb') as fpw:
+        await fpw.write(data)
+
+    async with aiofiles.open(tmpfile.name, mode='rb') as fpr:
+        await s3_client.upload_fileobj(fpr, bucket_name, 'test_file')
+
+    resp = await s3_client.get_object(Bucket=bucket_name, Key='test_file')
+    assert (await resp['Body'].read()) == data
+
+
 @pytest.mark.asyncio
 async def test_s3_upload_broken_fileobj(event_loop, s3_client, bucket_name):
     class BrokenFile(object):
